#include <iostream>
#include <map>
#include <vector>
#include <cassert>

using namespace std;

int gcd(int a, int b) {
  if (a < 0) a = -a;
  if (b < 0) b = -b;
  while (b > 0) {
    int c = a % b;
    a = b;
    b = c;
  }
  return a;
}

struct Point{
  int x, y;
  Point(int x, int y) : x(x), y(y) {}
};

struct Line{
  int dx, dy;
  Line(Point p);
  Line(Point p1, Point p2);
  bool operator < (const Line &r) const {
    return dx < r.dx || dx == r.dx && dy < r.dy;
  }
  void normalize();
};

Line::Line(Point p): dx(-p.y), dy(p.x){
  normalize();
}

Line::Line(Point p1, Point p2){
  dx = p2.x - p1.x;
  dy = p2.y - p1.y;
  normalize();
}

void Line::normalize() {
  assert(dx != 0 || dy != 0);
  if (dx < 0) {
    dx = -dx;
    dy = -dy;
  }
  if (dx == 0) {
    dy = 1;
    return;
  }
  if (dy == 0) {
    dx = 1;
    return;
  }
  int d = gcd(dx, dy);
  dx /= d; 
  dy /= d;
}

int main() {
  map<int, vector<Point> > points;
  map<Line, int> lines;
  int r, n;
  cin >> r >> n;
  bool zerozero = false;
  for (int i = 0; i < n; i++) {
    int x, y;
    cin >> x >> y;
    if (x == 0 && y == 0) {
      zerozero = true;
      continue;
    }
    int r2 = x*x + y*y;
    points[r2].push_back(Point(x, y));
  }
  if (zerozero) --n;

  map<int, vector<Point> >::iterator pit;
  for (pit = points.begin(); pit != points.end(); pit++) {
    vector<Point> &p = pit->second;
    for (int i = 0 ; i < p.size(); i++) {
      lines[Line(p[i])]++;
      for (int j = i + 1; j < p.size(); j++) {
          lines[Line(p[i], p[j])] += 2; 
      }
    }   
  }

  int maxCount = 0;
  map<Line, int>::iterator lit;
  map<Line, int>::iterator bit;
  for (lit = lines.begin(); lit != lines.end(); lit++) {
    if (lit->second > maxCount) {
      maxCount = lit->second;
      bit = lit;
    }
  }
  cout << n - maxCount << endl;

  return 0;
}
