import java.io.PrintWriter;
import java.util.HashSet;
import java.util.Scanner;

/**
 * Author: Oleg Strekalovsky
 * Date: 27.10.13
 * Time: 17:57
 */
public class OStGreedyWithRareRates2 {

    Scanner in;
    PrintWriter out;

    void solve() {
        int nMonstersType = in.nextInt();
        int maxNMonsters = in.nextInt();
        int nSkills = in.nextInt();
        boolean haveSkill[][] = new boolean[nMonstersType][nSkills];
        for (int monsterIdx = 0; monsterIdx < nMonstersType; monsterIdx++) {
            for (int skillIdx = 0; skillIdx < nSkills; skillIdx++) {
                if (in.nextInt() == 1) {
                    haveSkill[monsterIdx][skillIdx] = true;
                }
            }
        }
        HashSet<Integer> selectedMonsters = new HashSet<Integer>(maxNMonsters);
        HashSet<Integer> selectedSkills = new HashSet<Integer>(nSkills);
        int nSelectedMonsters = Math.min(maxNMonsters, nSkills);
        while (nSelectedMonsters > 0) {
            nSelectedMonsters--;
            int bestMonsterIdx = findBestMonsterIdx(selectedMonsters, selectedSkills, haveSkill);
            selectedMonsters.add(bestMonsterIdx);
            for (int skillIdx = 0; skillIdx < nSkills; skillIdx++) {
                if (haveSkill[bestMonsterIdx][skillIdx]) {
                    selectedSkills.add(skillIdx);
                }
            }
            //System.out.println(maxNMonsters+" nSkills:"+selectedSkills);
        }
        out.println(selectedSkills.size());
    }

    private int findBestMonsterIdx(HashSet<Integer> selectedMonsters, HashSet<Integer> selectedSkills, boolean[][] haveSkill) {
        int nMonsters = haveSkill.length;
        int maxNNewSkills = 0;
        int bestMonsterIdx = 0;
        for (int monsterIdx = 0; monsterIdx < nMonsters; monsterIdx++) {
            if (!selectedMonsters.contains(monsterIdx)) {
                int nNewSkills = getNNewSkills(monsterIdx, selectedSkills, haveSkill);
                if (maxNNewSkills < nNewSkills || nNewSkills == maxNNewSkills && getRarestSkillRate(bestMonsterIdx, selectedSkills, selectedMonsters, haveSkill) > getRarestSkillRate(monsterIdx, selectedSkills, selectedMonsters, haveSkill)) {
                    maxNNewSkills = nNewSkills;
                    bestMonsterIdx = monsterIdx;
                }
            }
        }
        return bestMonsterIdx;
    }

    private int getRarestSkillRate(int curMonsterIdx, HashSet<Integer> selectedSkills, HashSet<Integer> selectedMonsters, boolean[][] haveSkill) {
        int nSkills = haveSkill[0].length;
        int nMonsters = haveSkill.length;
        int minSkillRate = Integer.MAX_VALUE / 2;
        int rareSkillRates[] = new int[nSkills];
        for (int monsterIdx = 0; monsterIdx < nMonsters; monsterIdx++) {
            if (!selectedMonsters.contains(monsterIdx)) {
                for (int skillIdx = 0; skillIdx < nSkills; skillIdx++) {
                    if (haveSkill[monsterIdx][skillIdx] && !selectedSkills.contains(skillIdx)){
                        rareSkillRates[skillIdx]++;
                    }
                }
            }
        }
        for (int skillIdx = 0; skillIdx < rareSkillRates.length; skillIdx++) {
            if (haveSkill[curMonsterIdx][skillIdx] && !selectedSkills.contains(skillIdx)) {
                minSkillRate = Math.min(minSkillRate, rareSkillRates[skillIdx]);
            }
        }
        return minSkillRate;
    }

    private int getNNewSkills(int monsterIdx, HashSet<Integer> selectedSkills, boolean[][] haveSkill) {
        int nNewSkills = 0;
        for (int skillIdx = 0; skillIdx < haveSkill[0].length; skillIdx++) {
            if (haveSkill[monsterIdx][skillIdx] && !selectedSkills.contains(skillIdx)) {
                nNewSkills++;
            }
        }
        return nNewSkills;
    }


    void run() {
        in = new Scanner(System.in);
        out = new PrintWriter(System.out);
        try {
            solve();
        } finally {
            out.close();
        }
    }

    public static void main(String[] args) {
        new OStGreedyWithRareRates2().run();
    }
}
