import java.io.*;
import java.util.*;

public class Main {
	
	Scanner in;
	static PrintWriter out;

	static class Shard implements Comparable<Shard> {
		long count;
		int idx;
		
		Shard(long count, int idx) {
			this.count = count;
			this.idx = idx;
		}
		
		@Override
		public int compareTo(Shard second) {
			int res = (int)Math.signum(this.count - second.count);
			if (res == 0) {
				return this.idx - second.idx;
			} else {
				return res;
			}
		}
		
		public String toString() {
			return count + " " + idx;
		}
	}
	
	void printAnswer(Shard[] shards) {
		Arrays.sort(shards, new Comparator<Shard>() {
			@Override
			public int compare(Shard first, Shard second) {
				return first.idx - second.idx;
			}
		});
		boolean first = true;
		for (Shard sh : shards) {
			if (first) {
				first = false;
			} else {
				out.print(" ");
			}
			out.print(sh.count);
		}
		out.println();
	}
	
	void solveSmart(Shard []shards, long remainToAdd) {
		Arrays.sort(shards);
		
		int firstUsedLength = 1;
		for (int i = 1; i < shards.length; i++) {
			if (shards[i].count == shards[i - 1].count) {
				firstUsedLength++;
			} else {
				break;
			}
		}
		
		while (firstUsedLength < shards.length) {
			long diff = shards[firstUsedLength].count - shards[firstUsedLength - 1].count;
			asserT(diff > 0);
			if (firstUsedLength * diff >= remainToAdd) {
				break;
			} else {
				for (int i = 0; i < firstUsedLength; i++) {
					shards[i].count += diff;
				}
				remainToAdd -= firstUsedLength * diff;
				
				for (int i = firstUsedLength; i < shards.length; i++) {
					if (shards[i].count == shards[i - 1].count) {
						firstUsedLength++;
					} else {
						break;
					}
				}
			}
		}
		Arrays.sort(shards);
		long div = remainToAdd / firstUsedLength;
		long rem = remainToAdd % firstUsedLength;
		for (int i = 0; i < firstUsedLength; i++) {
			if (i < rem) {
				shards[i].count++;
			}
			shards[i].count += div;
		}
		printAnswer(shards);
	}
	
	void solve() {
		int nShards = in.nextInt();
		Shard[] shards = new Shard[nShards];
		Shard[] naive = new Shard[nShards];
		for (int i = 0; i < shards.length; i++) {
			int count = in.nextInt();
			asserT(count <= 1000000);
			shards[i] = new Shard(count, i);
			naive[i] = new Shard(count, i);
		}
		long k = in.nextLong();
		asserT(k <= 1000000000000L);
		
		solveSmart(shards, k);
	}
	
	static void asserT(boolean e) {
		if (!e) {
			throw new Error();
		}
	}
	
	public void run() {
		in = new Scanner(System.in);
		out = new PrintWriter(System.out);
	
		try {
			solve();
		} finally {
			out.close();
		}
	}
	
	public static void main(String[] args) {
		new Main().run();
	}
}
